==> eole-client_2.5.0-2.tar.gz: eole-client-2/sources/all/setup-gestion_postes.py <==
# _*_ coding: iso-8859-1 _*_
#!/usr/bin/env python

from distutils.core import setup
import py2exe
import os, shutil, sys, glob

from eole import versioneole

# pour l'import de win32com.shell
try:
    import modulefinder
    import win32com
    for p in win32com.__path__[1:]:
        modulefinder.AddPackagePath("win32com", p)
    for extra in ["win32com.shell"]: #,"win32com.mapi"
        __import__(extra)
        m = sys.modules[extra]
        for p in m.__path__[1:]:
            modulefinder.AddPackagePath(extra, p)
except ImportError:
    # no build path setup, no worries.
    pass
# #############

dist_dir = "dists\\gestion-postes"
if os.path.exists(dist_dir):
    shutil.rmtree(dist_dir)

if os.path.exists("build"):
    shutil.rmtree("build")

# recuperation des chemins contenant les DLLs
dll1 = os.path.join(os.path.abspath('.'), 'Py26dlls.MFC')
dll2 = os.path.join(os.path.abspath('.'), 'Py26dlls.MSV')
# Ajout de ces chemins au %PATH%
os.environ['path']=';'.join([os.environ['path'], dll1, dll2])
# Ajout des DLLS aux 'data_files'
Py26dllsMFC = glob.glob(r"Py26dlls.MFC\*.*")
Py26dllsMSV = glob.glob(r"Py26dlls.MSV\*.*")
data_files = [("", Py26dllsMSV),
              ("", Py26dllsMFC),
              ("", ['dlls\\gdiplus.dll']),
			  ("images", ["images\\banniere.jpg", "images\\eole.ico"]),
			  ("", ["eole_exe\\eole_conf.vnc"]),
     ]

opts = {"py2exe": {
                   "dist_dir": dist_dir,
                   "packages":["encodings",],
                   "optimize":1,
                    }
        }

setup(name="Gestion des postes clients windows",
      options=opts,
      version = versioneole.CLISCRIBE_VERSION,
      description = "Client Scribe",
      author="Eole",
      author_email="eole@ac-dijon.fr",
      url="http://eole.orion.education.fr/diffusion",
      windows=[{
          "script":'gestion-postes.py',
          "icon_resources":[(1, "images\\eole.ico")]
          }],
      data_files=data_files)

==> eole-client_2.6.1-2.tar.gz: eole-client-2/sources/all/setup-gestion_postes.py <==
# _*_ coding: iso-8859-1 _*_
#!/usr/bin/env python

from distutils.core import setup
import py2exe
import os, shutil, sys, glob

from eole import versioneole

# pour l'import de win32com.shell
try:
    import modulefinder
    import win32com
    for p in win32com.__path__[1:]:
        modulefinder.AddPackagePath("win32com", p)
    for extra in ["win32com.shell"]: #,"win32com.mapi"
        __import__(extra)
        m = sys.modules[extra]
        for p in m.__path__[1:]:
            modulefinder.AddPackagePath(extra, p)
except ImportError:
    # no build path setup, no worries.
    pass
# #############

dist_dir = "dists\\gestion-postes"
if os.path.exists(dist_dir):
    shutil.rmtree(dist_dir)

if os.path.exists("build"):
    shutil.rmtree("build")

# # recuperation des chemins contenant les DLLs
dll1 = os.path.join(os.path.abspath('.'), 'dlls')
# # Ajout de ces chemins au %PATH%
os.environ['path']=';'.join([os.environ['path'], dll1])
# # Ajout des DLLS aux 'data_files'
dlls = glob.glob(r"dlls\*.*")
data_files = [("", dlls),
			  ("images", ["images\\banniere.jpg", "images\\eole.ico"]),
			  ("", ["eole_exe\\eole_conf.vnc"]),
              ]

opts = {"py2exe": {
                   "dist_dir": dist_dir,
                   "packages":["encodings",],
                   "optimize":1,
                    }
        }

setup(name="Gestion des postes clients windows",
      options=opts,
      version = versioneole.CLISCRIBE_VERSION,
      description = "Client Eole",
      author="Eole",
      author_email="eole@ac-dijon.fr",
      url="http://eole.orion.education.fr/diffusion",
      windows=[{
          "script":'gestion-postes.py',
          "icon_resources":[(1, "images\\eole.ico")]
          }],
      data_files=data_files)
